==> haskell-hls-refactor-plugin-2.0.0.0-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-refactor-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-refactor-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-refactor-plugin-2.0.0.0-LBKVkmxIEJiDsm85IgYIHi
key:                  hls-refactor-plugin-2.0.0.0-LBKVkmxIEJiDsm85IgYIHi
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           zubin.duggal@gmail.com
author:               The Haskell IDE Team
synopsis:             Exactprint refactorings for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  642098a1bdb6f05660018fb8cb637dac
exposed:              True
exposed-modules:
    Development.IDE.GHC.Compat.ExactPrint Development.IDE.GHC.Dump
    Development.IDE.GHC.ExactPrint Development.IDE.Plugin.CodeAction
    Development.IDE.Plugin.CodeAction.Util

hidden-modules:
    Development.IDE.Plugin.CodeAction.Args
    Development.IDE.Plugin.CodeAction.ExactPrint
    Development.IDE.Plugin.CodeAction.PositionIndexed
    Development.IDE.Plugin.Plugins.AddArgument
    Development.IDE.Plugin.Plugins.Diagnostic
    Development.IDE.Plugin.Plugins.FillHole
    Development.IDE.Plugin.Plugins.FillTypeWildcard
    Development.IDE.Plugin.Plugins.ImportUtils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-refactor-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-refactor-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-refactor-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refactor-plugin
hs-libraries:         HShls-refactor-plugin-2.0.0.0-LBKVkmxIEJiDsm85IgYIHi
depends:
    aeson-2.1.2.1-G4Y2VMvw6jlHlUlOzfqhge base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    dlist-1.0-I6FB5Nlk17hG16fxQzZSEb
    extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK ghc-9.4.8 ghc-boot-9.4.8
    ghc-exactprint-1.6.1-C0Oiqfv79rb7N3Oe6rciyx
    ghcide-2.0.0.0-3DlUhCtF16XEaV5TtFcT3J
    hls-graph-2.0.0.0-6aKGFDEwcZ2Gewpz8C2a3M
    hls-plugin-api-2.0.0.0-BSQontPVPIA4EciidEETjs
    lens-5.2.3-DnVNcFpsuwMCXFWImXsY2L
    lsp-1.6.0.0-1RxTvmiJB0d2TzCGfgQy8D mtl-2.2.2
    regex-tdfa-1.3.2.3-ATHs20GYS4zCnV1KwOyBL0
    retrie-1.2.3-JTEAVjDSmcYKMwH6FHITJb
    syb-0.7.2.4-1AaSJ4gAQqF80sCpMGQHRf text-2.0.2
    text-rope-0.3-LQnOkPra7OBdPtjtRqXTz time-1.12.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:
    /usr/share/doc/haskell-hls-refactor-plugin/html/hls-refactor-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refactor-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-refactor-plugin-2.0.0.0-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-refactor-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-refactor-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-refactor-plugin-2.0.0.0-ChM2pnCAkLJ1J8wKiyEDxp
key:                  hls-refactor-plugin-2.0.0.0-ChM2pnCAkLJ1J8wKiyEDxp
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           zubin.duggal@gmail.com
author:               The Haskell IDE Team
synopsis:             Exactprint refactorings for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  bc5e288c5eee3a41433622880cd3c756
exposed:              True
exposed-modules:
    Development.IDE.GHC.Compat.ExactPrint Development.IDE.GHC.Dump
    Development.IDE.GHC.ExactPrint Development.IDE.Plugin.CodeAction
    Development.IDE.Plugin.CodeAction.Util

hidden-modules:
    Development.IDE.Plugin.CodeAction.Args
    Development.IDE.Plugin.CodeAction.ExactPrint
    Development.IDE.Plugin.CodeAction.PositionIndexed
    Development.IDE.Plugin.Plugins.AddArgument
    Development.IDE.Plugin.Plugins.Diagnostic
    Development.IDE.Plugin.Plugins.FillHole
    Development.IDE.Plugin.Plugins.FillTypeWildcard
    Development.IDE.Plugin.Plugins.ImportUtils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-refactor-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-refactor-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-refactor-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refactor-plugin
hs-libraries:         HShls-refactor-plugin-2.0.0.0-ChM2pnCAkLJ1J8wKiyEDxp
depends:
    aeson-2.1.2.1-6acn88DzD1XA00qNRJAJcm base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    dlist-1.0-I6FB5Nlk17hG16fxQzZSEb
    extra-1.7.16-7xWSq5sOOT2ClgTEM6hqi4 ghc-9.4.8 ghc-boot-9.4.8
    ghc-exactprint-1.6.1-JPafkSWbKoBAOASPJPVhY
    ghcide-2.0.0.0-9qUCbNTeV3PKPTFNBEOqKd
    hls-graph-2.0.0.0-JxXRDWFaqbJLJVHXjOUi26
    hls-plugin-api-2.0.0.0-7JHQKy5I48iFHpRVjutX3t
    lens-5.2.3-6LjFCusMfYNH72ou1m3jdq
    lsp-1.6.0.0-96SGiU71mGvLtJoU3VZPoO mtl-2.2.2
    regex-tdfa-1.3.2.4-4spaPYpacr92ooLlQb3epN
    retrie-1.2.3-AiQxahNgqWYBT4LgbDopcb
    syb-0.7.2.4-7bSc04XXCdy5oWDf8UOHZs text-2.0.2
    text-rope-0.3-7A8zFIQiYWi9e9cHtKo4j0 time-1.12.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-2kG5VEC3Gy42AwINT9WJ9w

haddock-interfaces:
    /usr/share/doc/haskell-hls-refactor-plugin/html/hls-refactor-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refactor-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
